Enum frame_support::storage::child::ChildInfo
pub enum ChildInfo {
ParentKeyId(ChildTrieParentKeyId),
}Expand description
Information related to a child state.
Variants
ParentKeyId(ChildTrieParentKeyId)
This is the one used by default.
Implementations
impl ChildInfo
impl ChildInfo
pub fn new_default(storage_key: &[u8]) -> ChildInfo
pub fn new_default(storage_key: &[u8]) -> ChildInfo
Instantiates child information for a default child trie
of kind ChildType::ParentKeyId, using an unprefixed parent
storage key.
pub fn new_default_from_vec(storage_key: Vec<u8, Global>) -> ChildInfo
pub fn new_default_from_vec(storage_key: Vec<u8, Global>) -> ChildInfo
Same as new_default but with Vec<u8> as input.
pub fn try_update(&mut self, other: &ChildInfo) -> bool
pub fn try_update(&mut self, other: &ChildInfo) -> bool
Try to update with another instance, return false if both instance are not compatible.
pub fn keyspace(&self) -> &[u8] ⓘ
pub fn keyspace(&self) -> &[u8] ⓘ
Returns byte sequence (keyspace) that can be use by underlying db to isolate keys.
This is a unique id of the child trie. The collision resistance of this value
depends on the type of child info use. For ChildInfo::Default it is and need to be.
pub fn storage_key(&self) -> &[u8] ⓘ
pub fn storage_key(&self) -> &[u8] ⓘ
Returns a reference to the location in the direct parent of this trie but without the common prefix for this kind of child trie.
pub fn prefixed_storage_key(&self) -> PrefixedStorageKey
pub fn prefixed_storage_key(&self) -> PrefixedStorageKey
Return a the full location in the direct parent of this trie.
pub fn into_prefixed_storage_key(self) -> PrefixedStorageKey
pub fn into_prefixed_storage_key(self) -> PrefixedStorageKey
Returns a the full location in the direct parent of this trie.
pub fn child_type(&self) -> ChildType
pub fn child_type(&self) -> ChildType
Returns the type for this child info.