Enum frame_support::storage::child::StateVersion
pub enum StateVersion {
V0,
V1,
}Expand description
Different possible state version.
V0 and V1 uses a same trie implementation, but V1 will write external value node in the trie for
value with size at least TRIE_VALUE_NODE_THRESHOLD.
Variants
Implementations
impl StateVersion
impl StateVersion
pub fn state_value_threshold(&self) -> Option<u32>
pub fn state_value_threshold(&self) -> Option<u32>
If defined, values in state of size bigger or equal to this threshold will use a separate trie node. Otherwhise, value will be inlined in branch or leaf node.